@@ -46,6 +46,8 @@ def token_expired() -> bool:
                 return True
             else:
                 return False
+    except KeyError:
+        return True
     except FileNotFoundError:
         return True
 
@@ -74,9 +76,10 @@ class Auth:
         self.password = password
         self.proxy = proxy
         self.__session = tls_client.Session(
-            client_identifier="chrome_105"
+            client_identifier="chrome_105",
         )
 
+
     @staticmethod
     def _url_encode(string: str) -> str:
         """
@@ -110,6 +113,7 @@ class Auth:
                 print(f"{Fore.GREEN}[OpenAI] {Fore.WHITE}Using proxy: {self.proxy}")
                 self.__session.proxies = proxies
 
+
         print(f"{Fore.GREEN}[OpenAI] {Fore.WHITE}Beginning auth process")
         # First, make a request to https://chat.openai.com/auth/login
         url = "https://chat.openai.com/auth/login"
